# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 1.0.x   | :white_check_mark: |
| < 1.0   | :x:                |

## Reporting a Vulnerability

We take security seriously. If you discover a security vulnerability within this project, please report it immediately.

**DO NOT** create a public GitHub issue for security vulnerabilities.

Instead, please send an email to [INSERT CONTACT EMAIL] or Report via GitHub Security Advisories if enabled.

We will acknowledge your report within 48 hours and will provide a more detailed response within 7 days, indicating the next steps.
